@@ -2,7 +2,7 @@
 #
 #  SPDX-License-Identifier: GPL-3.0-or-later
 
-from typing import Mapping, Optional, Sequence
+from typing import Any, Mapping, Optional, Sequence
 
 from gvm.protocols.gmp.requests import EntityID
 
@@ -114,28 +114,23 @@ class GMPNext(GMPv227[T]):
         agent_ids: list[EntityID],
         *,
         authorized: Optional[bool] = None,
-        min_interval: Optional[int] = None,
-        heartbeat_interval: Optional[int] = None,
-        schedule: Optional[str] = None,
+        config: Optional[Mapping[str, Any]] = None,
         comment: Optional[str] = None,
     ) -> T:
-        """Modify multiple agents
+        """
+        Modify multiple agents.
 
         Args:
-            agent_ids: List of agent UUIDs to modify
-            authorized: Whether the agent is authorized
-            min_interval: Minimum scan interval
-            heartbeat_interval: Interval for sending heartbeats
-            schedule: Cron-style schedule for agent
-            comment: Comment for the agents
+            agent_ids: List of agent UUIDs to modify.
+            authorized: Whether the agent is authorized.
+            config: Nested config for Agent Controller.
+            comment: Optional comment for the change.
         """
         return self._send_request_and_transform_response(
             Agents.modify_agents(
                 agent_ids=agent_ids,
                 authorized=authorized,
-                min_interval=min_interval,
-                heartbeat_interval=heartbeat_interval,
-                schedule=schedule,
+                config=config,
                 comment=comment,
             )
         )
@@ -150,6 +145,25 @@ class GMPNext(GMPv227[T]):
             Agents.delete_agents(agent_ids=agent_ids)
         )
 
+    def modify_agent_control_scan_config(
+        self,
+        agent_control_id: EntityID,
+        config: Mapping[str, Any],
+    ) -> T:
+        """
+        Modify agent control scan config.
+
+        Args:
+            agent_control_id: The agent control UUID.
+            config: Nested config for Agent Controller.
+        """
+        return self._send_request_and_transform_response(
+            Agents.modify_agent_control_scan_config(
+                agent_control_id=agent_control_id,
+                config=config,
+            )
+        )
+
     def get_agent_groups(
         self,
         *,
@@ -454,6 +468,49 @@ class GMPNext(GMPv227[T]):
             )
         )
 
+    def create_container_image_task(
+        self,
+        name: str,
+        oci_image_target_id: EntityID,
+        scanner_id: EntityID,
+        *,
+        comment: Optional[str] = None,
+        alterable: Optional[bool] = None,
+        schedule_id: Optional[EntityID] = None,
+        alert_ids: Optional[Sequence[EntityID]] = None,
+        schedule_periods: Optional[int] = None,
+        observers: Optional[Sequence[str]] = None,
+        preferences: Optional[Mapping[str, SupportsStr]] = None,
+    ) -> T:
+        """Create a new scan task using an OCI image target.
+
+        Args:
+            name: Name of the new task.
+            oci_image_target_id: UUID of the OCI image target to be scanned.
+            scanner_id: UUID of scanner to use for scanning the agents.
+            comment: Optional comment for the task.
+            alterable: Whether the task should be alterable.
+            alert_ids: List of UUIDs for alerts to be applied to the task.
+            schedule_id: UUID of a schedule when the task should be run.
+            schedule_periods: Limit to number of scheduled runs, 0 for unlimited.
+            observers: List of usernames or IDs allowed to observe the task.
+            preferences: Scanner preferences as name/value pairs.
+        """
+        return self._send_request_and_transform_response(
+            Tasks.create_container_image_task(
+                name=name,
+                oci_image_target_id=oci_image_target_id,
+                scanner_id=scanner_id,
+                comment=comment,
+                alterable=alterable,
+                schedule_id=schedule_id,
+                alert_ids=alert_ids,
+                schedule_periods=schedule_periods,
+                observers=observers,
+                preferences=preferences,
+            )
+        )
+
     def create_container_task(
         self, name: str, *, comment: Optional[str] = None
     ) -> T:
@@ -586,6 +643,7 @@ class GMPNext(GMPv227[T]):
         target_id: Optional[EntityID] = None,
         scanner_id: Optional[EntityID] = None,
         agent_group_id: Optional[EntityID] = None,
+        oci_image_target_id: Optional[EntityID] = None,
         alterable: Optional[bool] = None,
         hosts_ordering: Optional[HostsOrdering] = None,
         schedule_id: Optional[EntityID] = None,
@@ -604,6 +662,7 @@ class GMPNext(GMPv227[T]):
             target_id: UUID of target to be scanned
             scanner_id: UUID of scanner to use for scanning the target
             agent_group_id: UUID of agent group to use for scanning
+            oci_image_target_id: UUID of the OCI Image target to be scanned.
             comment: The comment on the task.
             alert_ids: List of UUIDs for alerts to be applied to the task
             hosts_ordering: The order hosts are scanned in
@@ -622,6 +681,7 @@ class GMPNext(GMPv227[T]):
                 target_id=target_id,
                 scanner_id=scanner_id,
                 agent_group_id=agent_group_id,
+                oci_image_target_id=oci_image_target_id,
                 alterable=alterable,
                 hosts_ordering=hosts_ordering,
                 schedule_id=schedule_id,
