@@ -7,6 +7,7 @@ from ...gmpnext import GMPTestCase
 from ...gmpnext.entities.tasks import (
     GmpCloneTaskTestMixin,
     GmpCreateAgentGroupTaskTestMixin,
+    GmpCreateContainerImageTaskTestMixin,
     GmpCreateContainerTaskTestMixin,
     GmpCreateTaskTestMixin,
     GmpDeleteTaskTestMixin,
@@ -30,6 +31,12 @@ class GmpCreateAgentGroupTaskTestCase(
     pass
 
 
+class GMPCreateContainerImageTaskTestCase(
+    GmpCreateContainerImageTaskTestMixin, GMPTestCase
+):
+    pass
+
+
 class GMPCreateContainerTaskTestCase(
     GmpCreateContainerTaskTestMixin, GMPTestCase
 ):
