@@ -11,23 +11,23 @@ class GmpCreateScanConfigTestMixin:
         self.gmp.create_scan_config("a1", "foo")
 
         self.connection.send.has_been_called_with(
-            "<create_config>"
-            "<copy>a1</copy>"
-            "<name>foo</name>"
-            "<usage_type>scan</usage_type>"
-            "</create_config>"
+            b"<create_config>"
+            b"<copy>a1</copy>"
+            b"<name>foo</name>"
+            b"<usage_type>scan</usage_type>"
+            b"</create_config>"
         )
 
     def test_create_scan_config_with_comment(self):
         self.gmp.create_scan_config("a1", "foo", comment="comment")
 
         self.connection.send.has_been_called_with(
-            "<create_config>"
-            "<comment>comment</comment>"
-            "<copy>a1</copy>"
-            "<name>foo</name>"
-            "<usage_type>scan</usage_type>"
-            "</create_config>"
+            b"<create_config>"
+            b"<comment>comment</comment>"
+            b"<copy>a1</copy>"
+            b"<name>foo</name>"
+            b"<usage_type>scan</usage_type>"
+            b"</create_config>"
         )
 
     def test_create_scan_config_missing_scan_config_id(self):
