@@ -8,18 +8,16 @@ from ...gmpv224.system.authentication import (
     GmpDescribeAuthTestMixin,
     GmpModifyAuthTestMixin,
 )
-from ...gmpv225 import Gmpv225TestCase
+from ...gmpv225 import GMPTestCase
 
 
-class Gmpv225AuthenticateTestCase(GmpAuthenticateTestMixin, Gmpv225TestCase):
+class Gmpv225AuthenticateTestCase(GmpAuthenticateTestMixin, GMPTestCase):
     pass
 
 
-class Gmpv225ModifyAuthTestCase(GmpModifyAuthTestMixin, Gmpv225TestCase):
+class Gmpv225ModifyAuthTestCase(GmpModifyAuthTestMixin, GMPTestCase):
     pass
 
 
-class Gmpv225DescribeAuthCommandTestCase(
-    GmpDescribeAuthTestMixin, Gmpv225TestCase
-):
+class Gmpv225DescribeAuthCommandTestCase(GmpDescribeAuthTestMixin, GMPTestCase):
     pass
