@@ -40,10 +40,3 @@ class GetScannerTypeFromStringTestCase(unittest.TestCase):
 
         with self.assertRaises(InvalidArgument):
             ScannerType.from_string("gmp")
-
-    def test_greenbone_sensor_scanner(self):
-        ct = ScannerType.from_string("5")
-        self.assertEqual(ct, ScannerType.GREENBONE_SENSOR_SCANNER_TYPE)
-
-        ct = ScannerType.from_string("greenbone")
-        self.assertEqual(ct, ScannerType.GREENBONE_SENSOR_SCANNER_TYPE)
