@@ -19,14 +19,14 @@ class OSPGetScanTestCase(unittest.TestCase):
         self.osp.get_scans(scan_id="123-456", details=False, pop_results=False)
 
         self.connection.send.has_been_called_with(
-            '<get_scans scan_id="123-456" details="0" pop_results="0"/>'
+            b'<get_scans scan_id="123-456" details="0" pop_results="0"/>'
         )
 
     def test_get_scans_default_params(self):
         self.osp.get_scans()
 
         self.connection.send.has_been_called_with(
-            '<get_scans details="1" pop_results="0"/>'
+            b'<get_scans details="1" pop_results="0"/>'
         )
 
 
